@@ -10,9 +10,7 @@ prod_mapper = {
 def get_current_client(prod):
     module = importlib.import_module('cloudplatform_auth')
     get_access_func = getattr(module, 'get_cas_access_info')
-    connection_config = get_access_func()
-    username, password, url = connection_config.get("username"), connection_config.get("password"), \
-                              connection_config.get("url")
+    url, username, password = get_access_func()
     return prod_mapper[prod](username, password, url)
 
 
