@@ -121,6 +121,10 @@ class CASEcsClient(CASClient):
         endpoint = "/cas/casrs/vm/addDevice"
         return self.common_request("put", endpoint, body=body_params)
 
+    def show_profiles(self, params=None):
+        endpoint = "/cas/casrs/profile"
+        return self.common_request("get", endpoint)
+
 
 
 
